@@ -39,7 +39,8 @@ from calculate.lib.utils.files import (
     DirectoryRCS, RCSError)
 from calculate.lib.utils.git import Git
 from calculate.builder.variables.action import Actions
-from calculate.lib.utils.portage import (Layman, EmergeLog, EmergeLogNamedTask,
+from calculate.lib.utils.portage import (Layman, EmergeLog, EmergeLogFiltered,
+                                         EmergeLogNamedTask,
                                          InstalledPackageInfo, EbuildInfoError,
                                          EbuildInfo, ChrootEix, getRequires,
                                          get_packages_files_directory,
@@ -1586,7 +1587,7 @@ class Builder(Update):
         :param builder_path:
         :return:
         """
-        task = EmergeLog(EmergeLogNamedTask(EmergeMark.Automagic),
+        task = EmergeLogFiltered(EmergeLogNamedTask(EmergeMark.Automagic),
                          prefix=builder_path)
 
         cache_list = ("/var/calculate/tmp/%s.checkdep" %
@@ -1763,7 +1764,7 @@ class Builder(Update):
                                                       nummax=self.pkgnummax,
                                                       package=str(pkg)))
                     pkg_fn = get_binary_file(
-                        pkg, self.clVars.Get('cl_builder_linux_pkgdir_full'))
+                        pkg, self.clVars.Get('cl_builder_pkgdir_full'))
                     bp = BinaryPackage(pkg_fn, work_dn)
                     try:
                         bp["RDEPEND"] = "{oldpkgs} {newpkgs}".format(
