@@ -37,8 +37,7 @@ class ClBuilderPrepareAction(Action):
                     TemplatesError,
                     BuilderError, GitError)
 
-    successMessage = __("Build prepared successfully in "
-                        "<font='white'>{cl_builder_path}</font>")
+    successMessage = __("Build prepared successfully in \"{cl_builder_path}\"")
     failedMessage = __("Preparing the build is failed")
     interruptMessage = __("Preparing manually interrupted")
 
