@@ -18,6 +18,7 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
+from calculate.lib.utils.binhosts import BinhostError
 from calculate.lib.utils.files import FilesError, isEmptyFile, readFile
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
@@ -75,7 +76,7 @@ class ClBuilderUpdateAction(Action):
     """
     # ошибки, которые отображаются без подробностей
     native_error = (DistributiveError, FilesError, UpdateError,
-                    TemplatesError,
+                    TemplatesError, BinhostError,
                     BuilderError, GitError, EmergeError)
 
     successMessage = None
@@ -152,6 +153,13 @@ class ClBuilderUpdateAction(Action):
                       'condition': lambda Get: Get(
                           'cl_builder_usetag_set') == "on"
                       },
+                     {'name': 'use_base_binhost',
+                      'method': 'Builder.set_base_binhost('
+                                'builder.cl_builder_binhost_base)',
+                      'condition': lambda Get, GetBool: (
+                            GetBool("builder.cl_builder_binhost_base_set") and
+                            Get("builder.cl_builder_binhost_base"))
+                      },
                      {'name': 'update_layman',
                       'message': __("Updating layman cache"),
                       'method': "Builder.update_layman(cl_builder_path)",
@@ -240,6 +248,12 @@ class ClBuilderUpdateAction(Action):
                       },
                  ]
                  },
+                {'name': 'use_base_binhost:index_pkgdir',
+                 'message': _("Prepare binary package directory"),
+                 'method': 'Builder.index_pkgdir(cl_builder_pkgdir,'
+                           'cl_builder_pkgdir_trunk,'
+                           'cl_builder_pkgdir_stable)'
+                 },
                 {'name': 'emerge_update_world',
                  'group': __("Updating packages"),
                  'tasks': [
@@ -353,6 +367,12 @@ class ClBuilderUpdateAction(Action):
                  ],
                  'depend': Tasks.has("update_other")
                  },
+                {'name': 'use_base_binhost:fix_pkgdir',
+                 'message': _("Update binary package directory"),
+                 'method': 'Builder.fix_pkgdir(cl_builder_pkgdir,'
+                           'cl_builder_pkgdir_trunk,'
+                           'cl_builder_pkgdir_stable)'
+                 },
                 {'name': 'update_other:check_automagic_group',
                  'group': __("Check for auto depends"),
                  'tasks': [
